@@ -4,7 +4,7 @@ import time
 import re
 import html
 from urllib.parse import urlparse
-from typing import Optional, Union, Dict, Any, Callable, List, BinaryIO
+from typing import Optional, Union, Dict, Any, Callable, List, BinaryIO, Tuple
 from pathlib import Path
 import os
 import mimetypes
@@ -204,9 +204,9 @@ class DiscordWebhook:
 
     def _prepare_file(
         self,
-        file: Union[str, Path, BinaryIO],
+        file: Union[str, bytes, BinaryIO],
         filename: Optional[str] = None
-    ) -> tuple[str, BinaryIO, str]:
+    ) -> Tuple[str, BinaryIO, str]:
         """
         Prepare file for upload, returning filename, file object, and content type.
         """
@@ -418,18 +418,6 @@ class DiscordWebhook:
     ) -> requests.Response:
         """
         Send a file or multiple files to Discord webhook.
-        
-        Args:
-            file: Single file or list of files (paths or file-like objects)
-            content: Optional message content
-            filename: Optional filename(s) for file-like objects
-            username: Optional webhook username override
-            avatar_url: Optional webhook avatar override
-            tts: Text-to-speech flag
-            embeds: Optional list of embeds
-            
-        Returns:
-            requests.Response: The response from Discord's API
         """
         files = []
         total_size = 0
@@ -459,17 +447,11 @@ class DiscordWebhook:
                     )
                 
                 files.append(
-                    (
-                        'files[{}]'.format(idx),
-                        (prepared_filename, file_obj, content_type)
-                    )
+                    ('file', (prepared_filename, file_obj, content_type))
                 )
 
             # Prepare payload
-            payload = {
-                "tts": tts
-            }
-            
+            payload = {}
             if content:
                 payload["content"] = content
             if username:
@@ -478,15 +460,18 @@ class DiscordWebhook:
                 payload["avatar_url"] = avatar_url
             if embeds:
                 payload["embeds"] = embeds
+            if tts:
+                payload["tts"] = tts
 
             self._validate_payload(payload)
 
             def make_request():
                 self.logger.debug(f"Sending webhook payload with {len(files)} files")
+                # Send as multipart/form-data
                 return self.session.post(
                     self.webhook_url,
-                    data={"payload_json": json.dumps(payload)},
                     files=files,
+                    data=payload,  # Send payload as data, not as payload_json
                     timeout=self.timeout
                 )
 
